2
0

SWDEV-305992 - Improve texture tests (#2646)

Enable more texture supports for hip-rocclr.
Skip texture tests on device that doesn't support images.
SWDEV-322257 - Fix issues of image tests skipped on
NVidia devices.

Change-Id: Ia99d06b1e97fc945f1b740e47710f4dcd70f38ca
Este cometimento está contido em:
ROCm CI Service Account
2022-05-09 21:16:20 +05:30
cometido por GitHub
ascendente ab3dc9ccac
cometimento 643f8dbd36
25 ficheiros modificados com 132 adições e 68 eliminações
+2
Ver ficheiro
@@ -25,7 +25,9 @@ THE SOFTWARE.
texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
outputData[y * width + x] = tex2D(tex, x, y);
#endif
}